==> cmsmadesimple-1.10.3-full.tar.gz: modules/MicroTiny/lang/ext/es_ES.php <==
<?php
$lang['friendlyname'] = 'MicroTiny - Editor WYSIWYG';
$lang['help'] = '<strong>&iquest;Que hace este m&oacute;dulo?</strong>
<br/>
MicroTiny es una versi&oacute;n reducida del editor TinyMCE, que fuera el editor predeterminado de CMS Made Simple.
Este no provee mas que una forma basica de editar contenido, pero sigue siendo una herramienta poderosa que permite cambios sencillos a contenido de paginas.
<br/><br/>
<strong>&iquest;Que puede fallar?</strong>
<br/>
MicroTiny se respalda sobre JavaScript, por lo que se requiere un navegador moderno. IE7+, y casi cualquier otro ser&aacute; suficiente.
En algunos servidores la opci&oacute;n de &#039;Usar configuraci&oacute;n est&aacute;tica&#039;  ser&aacute; necesaria para que este editor funcione. Probar eso si solamente se ve un editor simple sin botones WYSIWYG. Pero si funciona sin esta opci&oacute;n es mejor dejarlo como est&aacute;.';
$lang['example'] = 'Ejemplo MicroTiny';
$lang['settings'] = 'Ajustes';
$lang['youareintext'] = 'Usted est&aacute; en:';
$lang['dimensions'] = 'Ancho x Alto';
$lang['size'] = 'Tama&ntilde;o';
$lang['filepickertitle'] = 'Selector de archivos';
$lang['cmsmslinker'] = 'Enlazador de CMSMS ';
$lang['tmpnotwritable'] = 'La configuraci&oacute;n no pudo ser escrita al directorio tmp! Por favor arreglar eso!';
$lang['css_styles_text'] = 'Estilos CSS';
$lang['css_styles_help'] = 'Nombres de estilos CSS especificados aqui son agregados en un menu desplegable en el editor. Si se deja este campo vacio el menu desplegable no ser&aacute; visible (predeterminado).';
$lang['css_styles_help2'] = 'The styles can either be just the class name, or a classname with a new name to show.
Must be sepereated by either commas or newlines.
<br/>Example: mystyle1, My style name=mystyle
<br/>Result: a dropdown containing 2 entries, &#039;mystyle1&#039; and &#039;My stylename&#039; resulting in the insertion of mystyl1, and mystyle2 respectively.
<br/>Note: No checking for the actual existence of the stylenames are done. They are used blindly.';
$lang['usestaticconfig_text'] = 'Usar configuraci&oacute;n est&aacute;tica';
$lang['usestaticconfig_help'] = 'Esto genera un archivo est&aacute;tico de configuraci&oacute;n en vez de uno din&aacute;mico. Funciona mejor en algunos servidores (por ejemplo cuando se ejecuta PHP como CGI)';
$lang['allowimages_text'] = 'Permitir imagenes';
$lang['allowimages_help'] = 'Esto activa el bot&oacute;n de imagenes en la barra de herramientas, permitiendo insertar imagenes al contenido';
$lang['settingssaved'] = 'Ajustes guardados';
$lang['savesettings'] = 'Guardar ajustes';
$lang['utma'] = '156861353.661434885.1227567621.1254348603.1254357593.130';
$lang['utmz'] = '156861353.1254357593.130.50.utmcsr=cmsmadesimple.org|utmccn=(referral)|utmcmd=referral|utmcct=/';
$lang['qca'] = '1227207610-48391025-71477127';
$lang['utmc'] = '156861353';
$lang['utmb'] = '156861353.3.10.1254357593';
?>

==> cmsmadesimple-1.11-full.tar.gz: modules/MicroTiny/lang/ext/es_ES.php <==
<?php
$lang['force_blackonwhite'] = 'Forzar texto negro sobre fondo blanco';
$lang['help_force_blackonwhite'] = 'Forzar texto negro sobre fondo blanco para el editor MicroTiny. Esto permite ver mejor el texto en el editor WYSIWYG en ambientes con fondos obscuros y texto claro.';
$lang['strip_background'] = 'Remover efectos CSS de fondo';
$lang['help_strip_background'] = 'Remover efectos de fondo de las hojas de estilo afectadas. Esto permite ver mejor el texto en el editor WYSIWYG en ambientes con fondos obscuros y texto claro.';
$lang['show_statusbar'] = 'Mostrar barra de estatus';
$lang['help_show_statusbar'] = 'Habilitar la barra de estatus al pie del area WYSIWYG. Esto solo aplica en el area administrativa.';
$lang['allow_resize'] = 'Permitir redimensionar';
$lang['help_allow_resize'] = 'Permitir redimensinar el area WYSIWYG. Requiere que la barra de estatus Requires that the statusbar be enabled';
$lang['view_html'] = 'Ver HTML';
$lang['friendlyname'] = 'MicroTiny - Editor WYSIWYG';
$lang['help'] = '<strong>&iquest;Que hace este m&oacute;dulo?</strong>
<br/>
MicroTiny es una versi&oacute;n reducida del editor TinyMCE, que fuera el editor predeterminado de CMS Made Simple.
Este no provee mas que una forma basica de editar contenido, pero sigue siendo una herramienta poderosa que permite cambios sencillos a contenido de paginas.
<br/><br/>
<strong>&iquest;Que puede fallar?</strong>
<br/>
MicroTiny se respalda sobre JavaScript, por lo que se requiere un navegador moderno. IE7+, y casi cualquier otro ser&aacute; suficiente.
En algunos servidores la opci&oacute;n de &#039;Usar configuraci&oacute;n est&aacute;tica&#039;  ser&aacute; necesaria para que este editor funcione. Probar eso si solamente se ve un editor simple sin botones WYSIWYG. Pero si funciona sin esta opci&oacute;n es mejor dejarlo como est&aacute;.';
$lang['example'] = 'Ejemplo MicroTiny';
$lang['settings'] = 'Ajustes';
$lang['youareintext'] = 'Usted est&aacute; en:';
$lang['dimensions'] = 'Ancho x Alto';
$lang['size'] = 'Tama&ntilde;o';
$lang['filepickertitle'] = 'Selector de archivos';
$lang['cmsmslinker'] = 'Enlazador de CMSMS ';
$lang['tmpnotwritable'] = 'La configuraci&oacute;n no pudo ser escrita al directorio tmp! Por favor arreglar eso!';
$lang['css_styles_text'] = 'Estilos CSS';
$lang['css_styles_help'] = 'Nombres de estilos CSS especificados aqui son agregados en un menu desplegable en el editor. Si se deja este campo vacio el menu desplegable no ser&aacute; visible (predeterminado).';
$lang['css_styles_help2'] = 'The styles can either be just the class name, or a classname with a new name to show.
Must be sepereated by either commas or newlines.
<br/>Example: mystyle1, My style name=mystyle
<br/>Result: a dropdown containing 2 entries, &#039;mystyle1&#039; and &#039;My stylename&#039; resulting in the insertion of mystyl1, and mystyle2 respectively.
<br/>Note: No checking for the actual existence of the stylenames are done. They are used blindly.';
$lang['usestaticconfig_text'] = 'Usar configuraci&oacute;n est&aacute;tica';
$lang['usestaticconfig_help'] = 'Esto genera un archivo est&aacute;tico de configuraci&oacute;n en vez de uno din&aacute;mico. Funciona mejor en algunos servidores (por ejemplo cuando se ejecuta PHP como CGI)';
$lang['allowimages_text'] = 'Permitir imagenes';
$lang['allowimages_help'] = 'Esto activa el bot&oacute;n de imagenes en la barra de herramientas, permitiendo insertar imagenes al contenido';
$lang['settingssaved'] = 'Ajustes guardados';
$lang['savesettings'] = 'Guardar ajustes';
$lang['utma'] = '156861353.1603343530.1339275764.1339275764.1339275764.1';
$lang['utmz'] = '156861353.1339275764.1.1.utmccn=(direct)|utmcsr=(direct)|utmcmd=(none)';
$lang['utmc'] = '156861353';
$lang['utmb'] = '156861353';
?>
